@@ -31,7 +31,7 @@ class SubprocessResults(object):
             setattr(self, key, value)
 
 
-def run_in_subprocess(cmd, check_output=False, ** kwargs):
+def run_in_subprocess(cmd, check_output=False, **kwargs):
     """
     Execute command using default subprocess configuration.
 
@@ -64,10 +64,10 @@ def run_in_subprocess(cmd, check_output=False, ** kwargs):
     try:
         stdout, stderr = process.communicate(None, timeout=timeout)
     except subprocess.TimeoutExpired:
-        os.killpg(os.getpgid(process.pid), signal.SIGINT)  # send signal to the process group, recurively killing all children
+        os.killpg(os.getpgid(process.pid), signal.SIGINT)  # send signal to the process group, recursively killing all children
         output, unused_err = process.communicate()
         raise subprocess.TimeoutExpired(process.args, timeout, output=output)
-    return SubprocessResults(returncode=process.returncode, stdout=stdout or '', stderr=stderr or '')
+    return SubprocessResults(returncode=process.returncode, stdout=stdout or b'', stderr=stderr or b'')
 
 
 class TimeoutError(Exception):
